@@ -120,6 +120,13 @@ def validate_estimator(value: str) -> str:
     raise typer.BadParameter("Invalid estimation model " + value + " available models are: " + str(movado.models))
 
 
+def validate_controller(value: str) -> str:
+    movado = Movado()
+    if value in movado.controllers:
+        return value
+    raise typer.BadParameter("Invalid controller " + value + " available controllers are: " + str(movado.controllers))
+
+
 def validate_board(value: str) -> str:
     parts = get_parts()
     if value in set(parts.keys()):
