@@ -313,14 +313,14 @@ def space(
         }
     )
 
-    result = optimize(
+    execution_time = optimize(
         fitness_evaluator,
         ranges_dict,
         metrics,
         optimization_runtime,
         power_of_2,
     )
-    print("Optimization Result: " + str(result))
+    print("\n\nExecution Time: " + str(execution_time) + "\n\n")
 
 
 main()
